( cd usr/lib64 ; rm -rf libI810XvMC.so.1 )
( cd usr/lib64 ; ln -sf libI810XvMC.so.1.0.0 libI810XvMC.so.1 )
( cd usr/lib64 ; rm -rf libI810XvMC.so )
( cd usr/lib64 ; ln -sf libI810XvMC.so.1.0.0 libI810XvMC.so )
